clear all
set more off
cd "N:\UCSF ARS\RITM0160535\2018 1216"

capture log close
log using "../../Data/In/Vasco/data_build_log", replace

*************************
**** 1. DEMOGRAPHICS ****
*************************
import delimited "PtDemo_final.csv", clear

/* gender */
tab gender, m sort
gen male = gender == "M"
tab male, m sort
drop gender

/* race */
replace race = lower(race)
replace race = "white" if substr(raceid,1,5) == "white"
replace race = "black" if substr(raceid,1,5) == "black"
replace race = "asian" if substr(raceid,1,5) == "asian"
replace race = "native" if substr(raceid,1,6) == "native" | substr(raceid,1,8) == "american"
replace race = "other" if race != "white" & race != "black" & race != "asian" & race != "native"
tab raceid, sort m

encode raceid, gen(race)
tab race, sort m
drop raceid

gen white = race == 5
gen black = race == 2
gen asian = race == 1

/* ethnicity */
replace ethnicity = lower(ethnicity)
replace ethnicity = "not hispanic" if substr(ethnicity,1,12) == "not hispanic"
replace ethnicity = "hispanic" if substr(ethnicity,1,8) == "hispanic"
replace ethnicity = "unknown" if ethnicity != "not hispanic" & ethnicity != "hispanic"
tab ethnicityid, sort m

encode ethnicityid, gen(ethnicity)
tab ethnicity, sort m
drop ethnicityid

gen white_non_hisp = race == 5 & eth > 1
gen hispan = ethn == 1
drop ethnicity race

/* language */
replace language = lower(language)
replace language = "english" if substr(language,1,7) == "english"
replace language = "spanish" if substr(language,1,7) == "spanish"
replace language = "cantonese" if substr(language,1,9) == "cantonese"
replace language = "other" if language != "english" & language != "spanish" & language != "cantonese"
tab language, sort m

encode languageid, gen(language)
tab language, sort m
drop languageid

gen english = lang  == 2
gen spanish = lang == 4
gen canton = lang == 1
drop language

/*
/* SSN, HSF, CMAP */
tab ssn_yn, sort m
encode ssn_yn, gen(ssn_latest)
tab ssn_latest, sort m
recode ssn_latest (2=1) (1=0)
tab ssn_latest, sort m nol
drop ssn_yn

tab cmap_current, sort m
encode cmap_current, gen(cmap_latest)
tab cmap_latest, sort m
recode cmap_latest (1=0) (3=1) (2=.)
tab cmap_latest, sort m nol
drop cmap_current

tab hsf_current, sort m
encode hsf_current, gen(hsf_latest)
tab hsf_latest, sort m
recode hsf_latest (1=0) (3=1) (2=.)
tab hsf_latest, sort m nol
drop hsf_current
*/

/* clean and save */
rename age age
label var age "At last encounter"
replace age = min(age, 110)

drop deceased fc*  cmap* ssn *current

label var english "English language"
label var spanish "Spanish language"
label var canton "Cantonese language"

sum
desc
qui compress

isid ptid
sort ptid
order ptid male age white* black asian hisp eng span canton

save "../../Data/In/Vasco/PtDemo_final.dta", replace

*************************
****** 2. ENCOUNTER *****
*************************
import delimited "encFC_final.csv", clear

/* age */
rename ageatenc age_at_encounter
replace age_at_encounter = min(age_at_encounter, 110)
label var age_at_encounter "Age at encounter"

/* date */
gen date = date(encounterdate, "YMD")
format date %td
gen week = wofd(date)
format week %tw
list date encounterdate week in 1/20
drop encounterdate

/* CMAP, HSF */
/*
tab cmap_yn, sort m
encode cmap_yn, gen(cmap_current)
tab cmap_current, sort m
recode cmap_current (1=0) (3=1) (2=.)
tab cmap_current, sort m nol
drop cmap_yn
*/
tab hsf_yn, sort m
encode hsf_yn, gen(hsf)
tab hsf, sort m
recode hsf (1=0) (3=1) (2=.)
tab hsf, sort m nol
drop hsf_yn

tab everhs, sort m
encode everhs, gen(hsf_ever_old)
tab hsf_ever_old, sort m
recode hsf_ever_old (1=0) (2=1)
tab hsf_ever_old, sort m nol
drop everhs

/*
tab evercmap, sort m
encode evercmap, gen(cmap_ever_old)
tab cmap_ever_old, sort m
recode cmap_ever_old (1=0) (2=1)
tab cmap_ever_old, sort m nol
drop evercmap
*/

/* transfer hsf_ever_old, yob vars to demographics database */
preserve
gen year = year(date), after(date)
list date year in 1/10
gen yob = year - age, after(age)
list yob year age in 1/10
*drop cmap_ever_old

collapse (max) hsf_ever_old (mean) yob, by(ptid)

replace yob = int(yob)
label var yob "Year of birth"

sum
merge 1:1 ptid using "../../Data/In/Vasco/PtDemo_final.dta"
assert _merge == 3
drop _merge

label var hsf_ever_old "HSF Ever original version"

order ptid yob male age white* black asian hisp eng span canton hsf*
qui compress
save "../../Data/In/Vasco/PtDemo_final.dta", replace
restore

drop *ever*
/*		*/

/* hospital service codes */
merge m:1 hospsvc using "../../Data/In/Vasco/HSPSVC_dictionary.dta"
assert _merge == 3
drop _merge
drop hospsvc hospsvcd

/* financial codes */
merge m:1 fc using "../../Data/In/Vasco/FC_dictionary.dta", keepusing(fcode)
assert _merge == 3
drop _merge

/* reshape to patient-date level */
preserve
collapse (max) hsf*, by(ptid date week)
tempfile edno
save `edno'
restore

keep ptid hspsvc date week fcode age
bysort ptid date: gen v = _n   // number of insurance claims per visit
tab v, sort
bysort ptid date: keep if _n <= 2   // keep only 2 FCs per encounter -> 98.8% of obs

reshape wide fcode hspsvc, i(ptid date week) j(v)

merge 1:1 ptid date using `edno'
assert _merge == 3
drop _merge
/* 		*/

/* Outpatient emergency */ // at least one visit is such
gen emerg = inlist(hspsvc1, 51, 63)
replace emerg = 1 if inlist(hspsvc2, 51, 63)

/* lab visits */ 
gen lab = inlist(hspsvc1, 27, 65)
replace lab = 1 if inlist(hspsvc2, 27, 65)

/* dental clinic visit */
gen dental = inlist(hspsvc1, 13, 60, 71, 73, 79, 47, 48)
replace dental = 1 if inlist(hspsvc2, 13, 60, 71, 73, 79, 47, 48)

/* mental health visit */
gen psych = inlist(hspsvc1, 63, 64, 32, 33)
replace psych = 1 if inlist(hspsvc2, 63, 64, 32, 33)

/* urgent care visit */
gen urgentc = inlist(hspsvc1, 85)
replace urgentc = 1 if inlist(hspsvc2, 85)

/* primary care / family clinic visit */
gen primaryc = 0
replace primaryc = 1 if inlist(hspsvc1, 8,9,11,12,13,14,15,17,19)  
replace primaryc = 1 if inlist(hspsvc1, 20,21,22,23,28,29,30)   
replace primaryc = 1 if inlist(hspsvc1, 38,39,44,45,53,59,60,61,62)   				
replace primaryc = 1 if inlist(hspsvc1, 69,70,71,73,74,75,76,77) 
replace primaryc = 1 if inlist(hspsvc1, 79,80,81,82,91) 

replace primaryc = 1 if inlist(hspsvc2, 8,9,11,12,13,14,15,17,19)  
replace primaryc = 1 if inlist(hspsvc2, 20,21,22,23,28,29,30)   
replace primaryc = 1 if inlist(hspsvc2, 38,39,44,45,53,59,60,61,62)   				
replace primaryc = 1 if inlist(hspsvc2, 69,70,71,73,74,75,76,77) 
replace primaryc = 1 if inlist(hspsvc2, 79,80,81,82,91) 

/* MediCal & patient pay */
gen medical = inlist(fcode1, 6, 9,10,11,20,22)
replace medical = 1 if inlist(fcode2, 6, 9,10,11,20,22)
tab medical, sort m

gen patient_pay = inlist(fcode1, 16,19)
replace patient_pay = 1 if inlist(fcode2, 16,19)
tab patient_pay, sort m

/* fix missing hsf observations */
replace hsf = 1 if hsf == . & fcode1 == 5
replace hsf = 1 if hsf == . & fcode2 == 5
replace hsf = 0 if hsf == .

/* clean and save */
sum
desc

drop age

label var fcode1 "financial claim code #1"
label var fcode2 "financial claim code #2"
label var hspsvc1 "hospital service code #1"
label var hspsvc2 "hospital service code #2"

label var dental "dental clinic visit"
label var psych "mental health clinic visit"
label var emerg "emergency room visit"
label var lab "laboratory room visit"
label var urgentc "urgent care clinic visit"
label var primaryc "primary care/familiy clinic visit"
label var hsf "healthy SF claim"
label var medical "medical claim"
label var patient_pay "patient pay claim"

order ptid date week fc* hspsvc* hsf medical patient_pay 
sort date ptid
isid ptid date
qui compress

save "../../Data/In/Vasco/encFC_final.dta", replace

*************************
****** 3. ICD CODES *****
*************************
import delimited "PtDx_final.csv", clear
drop icddescr encnum

/* date */
gen date = date(dxdate, "YMD")
format date %td
gen week = wofd(date)
format week %tw
list date dxdate week in 1/20
drop dxdate

/* reshape to patient-day level */
bysort ptid date: gen v = _n
drop if v > 15     // !! keeping only first 15 diagnoses [10 diagnoses are 93.88% of sample (& 96.9% of ptid-date obs)]
reshape wide icdcode, i(ptid date week) j(v)

/* pregnancy and delivery visits */
* https://www.icd10data.com/ICD10CM/Codes/O00-O9A
* broad definition
gen pregnancy = 0
forvalues j = 1/15 {
	replace pregnancy = 1 if substr(icdcode`j',1,1) == "O"   // Pregnancy, childbirth and the puerperium
	}
tab pregnancy, m

/* clean ICD Codes a bit */
forvalues j = 1/15 {
	di "ICD CODE VARIABLE NUMBER `j'"
	replace icdcode`j' = upper(icdcode`j')
	replace icdcode`j' = trim(icdcode`j')
	
	di "TOTAL NUMBER OF OBS"
	count if icdcode`j' != ""   // total number obs
	count if substr(icdcode`j', 4, 1) != "." & strlen(icdcode`j') > 3  &  icdcode`j' != "" // number obs without a dot in 4th place
	di "NUMBER OBS WITHOUT DOT IN 4TH PLACE"
*	replace icdcode`j' = "" if substr(icdcode`j', 4, 1) != "." & strlen(icdcode`j') > 3
	count if inlist(substr(icdcode`j',1,1), "1", "2", "3", "4", "5", "6", "7", "8", "9") == 1 &  icdcode`j' != ""  // number obs without a letter in first place
	di "NUMBER OBS WITH A DIGIT IN 1ST PLACE"
*	replace icdcode`j' = "" if inlist(substr(icdcode`j',1,1), "1", "2", "3", "4", "5", "6", "7", "8", "9") == 0
	di "---------"
	di "---------"
}

gen acs = 0
forvalues j = 1/15 {

	di "ICD CODE VARIABLE NUMBER `j'"
	
	* Angina
	replace acs = 1 if substr(icdcode`j',1,5) == "I20.0" | substr(icdcode`j',1,5) == "I20.1" | substr(icdcode`j',1,5) == "I20.8" | substr(icdcode`j',1,5) == "I20.9" 
	replace acs = 1 if substr(icdcode`j',1,5) == "I24.0" | substr(icdcode`j',1,5) == "I24.8" | substr(icdcode`j',1,5) == "I20.9" | substr(icdcode`j',1,5) == "R07.2"

	* Asthma
	replace acs = 1 if inlist(icdcode`j', "J45.20", "J45.21", "J45.22", "J45.30", "J45.31", "J45.32", "J45.40", "J45.41", "J45.42")
	replace acs = 1 if inlist(icdcode`j', "J45.51", "J45.52", "J45.901", "J45.902", "J45.909", "J45.990", "J45.998", "J45.50")

	* Bacterial Pneumonia
	replace acs = 1 if substr(icdcode`j',1,3) == "J13" | substr(icdcode`j',1,3) == "J14" | substr(icdcode`j',1,5) == "J15.3" | substr(icdcode`j',1,5) == "J15.4" | substr(icdcode`j',1,5) == "J15.7" | substr(icdcode`j',1,5) == "J15.9"
	replace acs = 1 if substr(icdcode`j',1,5) == "J16.0" | substr(icdcode`j',1,5) == "J16.8" | substr(icdcode`j',1,5) == "J18.0" | substr(icdcode`j',1,5) == "J18.1"  | substr(icdcode`j',1,5) == "J18.2" | substr(icdcode`j',1,5) == "J18.8" | substr(icdcode`j',1,5) == "J18.9" 
		
	* Cellulitis	
	replace acs = 1 if substr(icdcode`j',1,5) == "I89.1"
	replace acs = 1 if inlist(icdcode`j', "L03.011" ,"L03.012" ,"L03.019" ,"L03.021" ,"L03.022" ,"L03.029" ,"L03.031" ,"L03.032" ,"L03.039")   
	replace acs = 1 if inlist(icdcode`j', "L03.111" ,"L03.112" ,"L03.113" ,"L03.114" ,"L03.115" ,"L03.116" ,"L03.119" ,"L03.121" ,"L03.122")   
	replace acs = 1 if inlist(icdcode`j', "L03.126" ,"L03.129" ,"L03.211" ,"L03.212" ,"L03.213" ,"L03.221" ,"L03.011" ,"L03.222" ,"L03.311")   	 
	replace acs = 1 if inlist(icdcode`j', "L03.315" ,"L03.316" ,"L03.317" ,"L03.319" ,"L03.321" ,"L03.322" ,"L03.323" ,"L03.324" ,"L03.325")  

	replace acs = 1 if inlist(icdcode`j', "L03.041" ,"L03.042" ,"L03.049")   
	replace acs = 1 if inlist(icdcode`j', "L03.123" ,"L03.124" ,"L03.125")   
	replace acs = 1 if inlist(icdcode`j', "L03.312" ,"L03.313" ,"L03.314")   	 
	replace acs = 1 if inlist(icdcode`j', "L03.326" ,"L03.327" ,"L03.329")  
	
	replace acs = 1 if inlist(icdcode`j', "L03.811" ,"L03.818" ,"L03.891" ,"L03.898")
	replace acs = 1 if inlist(icdcode`j', "L03.90", "L03.91")
   
	replace acs = 1 if substr(icdcode`j',1,5) == "L04.0" | substr(icdcode`j',1,5) == "L04.1" | substr(icdcode`j',1,5) == "L04.2" |  substr(icdcode`j',1,5) == "L04.3" |  substr(icdcode`j',1,5) == "L04.8" |  substr(icdcode`j',1,5) == "L04.9"	   
	replace acs = 1 if substr(icdcode`j',1,5) == "L08.0" | substr(icdcode`j',1,5) == "L08.1" |  substr(icdcode`j',1,5) == "L08.9"   
	replace acs = 1 if substr(icdcode`j',1,3) == "L88" | substr(icdcode`j',1,5) == "L98.0" | substr(icdcode`j',1,5) == "J34.0"
	replace acs = 1 if inlist(icdcode`j', "L08.81", "L08.82", "L08.89")
	
	* Congestive heart failure
	replace acs = 1 if inlist(icdcode`j', "I50.20", "I50.21", "I50.22", "I50.23", "I50.30", "I50.31", "I50.32", "I50.33", "I50.40")
	replace acs = 1 if inlist(icdcode`j', "I50.42", "I50.43", "I50.810", "I50.811", "I50.812", "I50.813", "I50.814", "I50.82", "I50.84")
	replace acs = 1 if inlist(icdcode`j', "I50.41", "I50.89")	
	replace acs = 1 if substr(icdcode`j', 1, 5) == "I50.1" | substr(icdcode`j', 1, 5) == "I50.9" | substr(icdcode`j', 1, 5) == "I11.0" | substr(icdcode`j', 1, 5) == "J81.0"

	* Chronic obstructive pulmonary disease
	replace acs = 1 if substr(icdcode`j',1,5) == "J20.0" | substr(icdcode`j',1,5) == "J20.1" | substr(icdcode`j',1,5) == "J20.2" | substr(icdcode`j',1,5) == "J20.3" | substr(icdcode`j',1,5) == "J20.4" | substr(icdcode`j',1,5) == "J20.5" | substr(icdcode`j',1,5) == "J20.6" | substr(icdcode`j',1,5) == "J20.7" | substr(icdcode`j',1,5) == "J20.8" | substr(icdcode`j',1,5) == "J20.9" 
	replace acs = 1 if substr(icdcode`j',1,3) == "J40"
	replace acs = 1 if substr(icdcode`j',1,5) == "J41.0" | substr(icdcode`j',1,5) == "J41.1" | substr(icdcode`j',1,5) == "J41.8"
	replace acs = 1 if substr(icdcode`j',1,3) == "J42"
	replace acs = 1 if substr(icdcode`j',1,5) == "J43.0" | substr(icdcode`j',1,5) == "J43.2" | substr(icdcode`j',1,5) == "J43.8" | substr(icdcode`j',1,5) == "J43.9"
	replace acs = 1 if substr(icdcode`j',1,5) == "J44.0" | substr(icdcode`j',1,5) == "J44.1" | substr(icdcode`j',1,5) == "J44.9"
	replace acs = 1 if substr(icdcode`j',1,5) == "J47.0" | substr(icdcode`j',1,5) == "J47.1" | substr(icdcode`j',1,5) == "J47.9"
	
	* Dehydration and gastroenteritis
	replace acs = 1 if substr(icdcode`j',1,5) == "E86.0" | substr(icdcode`j',1,5) == "E86.1" | substr(icdcode`j',1,5) == "E86.9"
	
	* Infectious/food-borne gastroenteritis
	replace acs = 1 if substr(icdcode`j',1,5) == "A02.0" | substr(icdcode`j',1,5) == "A04.1" | substr(icdcode`j',1,5) == "A04.2" | substr(icdcode`j',1,5) == "A04.3" | substr(icdcode`j',1,5) == "A04.4" | substr(icdcode`j',1,5) == "A04.5" | substr(icdcode`j',1,5) == "A02.6" | substr(icdcode`j',1,6) == "A04.71" | substr(icdcode`j',1,6) == "A04.72" | substr(icdcode`j',1,5) == "A04.8" | substr(icdcode`j',1,5) == "A04.9"
	replace acs = 1 if substr(icdcode`j',1,5) == "A05.9" | substr(icdcode`j',1,5) == "A07.2" | substr(icdcode`j',1,5) == "A08.0"
	replace acs = 1 if substr(icdcode`j',1,5) == "A08.2" 
	replace acs = 1 if substr(icdcode`j',1,5) == "A08.4" | substr(icdcode`j',1,5) == "A08.8" | substr(icdcode`j',1,3) == "A09" | substr(icdcode`j',1,5) == "A05.0" | substr(icdcode`j',1,5) == "A05.2"  | substr(icdcode`j',1,5) == "A05.3"  | substr(icdcode`j',1,5) == "A05.4" | substr(icdcode`j',1,5) == "A05.8" | substr(icdcode`j',1,5) == "A08.2"
	
	replace acs = 1 if inlist(icdcode`j', "A08.11", "A08.19", "A08.31", "A08.32", "A08.39")
	
	* Dental conditions
	replace acs = 1 if inlist(icdcode`j', "K02.51", "K02.52", "K02.53", "K02.61", "K02.62", "K02.63", "K03.81", "K03.89")
	replace acs = 1 if inlist(icdcode`j', "K04.01", "K04.02", "K04.90", "K04.99", "K05.00", "K05.01", "K05.10", "K05.11")
	replace acs = 1 if inlist(icdcode`j', "K05.211", "K05.212", "K05.213", "K05.219", "K05.221", "K05.222", "K05.223", "K05.229", "K05.30")
	replace acs = 1 if inlist(icdcode`j', "K05.322", "K05.323", "K05.329", "K05.321")
	replace acs = 1 if inlist(icdcode`j', "K06.010", "K06.011", "K06.012", "K06.013", "K06.020", "K06.021", "K06.022", "K06.023")
	
	replace acs = 1 if substr(icdcode`j',1,5) == "K02.3" | substr(icdcode`j',1,5) == "K02.7" | substr(icdcode`j',1,5) == "K02.9" | substr(icdcode`j',1,5) == "K03.0" | substr(icdcode`j',1,5) == "K03.1" | substr(icdcode`j',1,5) == "K03.2" | substr(icdcode`j',1,5) == "K03.3" | substr(icdcode`j',1,5) == "K03.4" | substr(icdcode`j',1,5) == "K03.5" | substr(icdcode`j',1,5) == "K03.6" | substr(icdcode`j',1,5) == "K03.7" | substr(icdcode`j',1,5) == "K03.9"
	replace acs = 1 if substr(icdcode`j',1,5) == "K04.1" | substr(icdcode`j',1,5) == "K04.2" | substr(icdcode`j',1,5) == "K04.4" | substr(icdcode`j',1,5) == "K04.5" | substr(icdcode`j',1,5) == "K04.6" | substr(icdcode`j',1,5) == "K04.7" | substr(icdcode`j',1,5) == "K04.8" 
	replace acs = 1 if substr(icdcode`j',1,5) == "K05.4" | substr(icdcode`j',1,5) == "K05.5" | substr(icdcode`j',1,5) == "K05.6" | substr(icdcode`j',1,5) == "K06.1" | substr(icdcode`j',1,5) == "K06.2" | substr(icdcode`j',1,5) == "K06.3" | substr(icdcode`j',1,5) == "K06.8" | substr(icdcode`j',1,5) == "K06.9"

	replace acs = 1 if substr(icdcode`j',1,5) == "K08.0" | substr(icdcode`j',1,5) == "K08.9 K08.3" | substr(icdcode`j',1,5) == "K13.3" | substr(icdcode`j',1,5) == "K13.4" | substr(icdcode`j',1,5) == "K13.5" | substr(icdcode`j',1,5) == "K13.6" | substr(icdcode`j',1,5) == "K12.0" | substr(icdcode`j',1,5) == "K12.1" | substr(icdcode`j',1,5) == "K12.2" | substr(icdcode`j',1,5) == "K13.0" | substr(icdcode`j',1,5) == "K13.1" | substr(icdcode`j',1,5) == "A69.0" | substr(icdcode`j',1,5) == "K09.8"
	replace acs = 1 if inlist(icdcode`j', "K08.54", "K08.55", "K08.56", "K08.59", "K08.81", "K08.82", "K08.89", "K08.20", "K08.21") 
	replace acs = 1 if inlist(icdcode`j', "K08.22", "K08.23", "K08.24", "K08.25", "K08.26", "K08.50", "K08.51", "K08.52")
	replace acs = 1 if inlist(icdcode`j', "K12.30", "K12.31", "K12.32", "K12.33", "K12.39", "K13.21", "K13.22", "K13.23", "K13.24") 
	replace acs = 1 if inlist(icdcode`j', "K13.29", "K13.70: K13.79", "M27.61", "M27.62", "M27.63", "M27.69")

	replace acs = 1 if inlist(icdcode`j', "K08.101", "K08.102", "K08.102", "K08.103", "K08.104", "K08.109", "K08.111", "K08.112", "K08.113")
	replace acs = 1 if inlist(icdcode`j', "K08.119", "K08.121", "K08.122", "K08.123", "K08.124", "K08.129", "K08.131", "K08.191", "K08.192")
	replace acs = 1 if inlist(icdcode`j', "K08.194", "K08.199", "K08.411", "K08.412", "K08.413", "K08.414", "K08.419", "K08.421", "K08.422")
	replace acs = 1 if inlist(icdcode`j', "K08.424", "K08.429", "K08.431", "K08.432", "K08.433", "K08.434", "K08.439", "K08.491", "K08.492")
	
	replace acs = 1 if inlist(icdcode`j', "K08.114", "K08.193", "K08.423", "K08.493")
	replace acs = 1 if inlist(icdcode`j', "K08.494", "K08.499", "K08.530", "K08.531", "K08.539") 

	* Diabetes complications
	replace acs = 1 if substr(icdcode`j',1,5) == "E11.8" | substr(icdcode`j',1,5) == "E10.8" | substr(icdcode`j',1,5) == "E10.9" | substr(icdcode`j',1,5) == "E11.9" | substr(icdcode`j',1,5) == "E10.8" | substr(icdcode`j',1,5) == "E10.9"
	
	replace acs = 1 if inlist(icdcode`j', "E10.10", "E10.11", "E13.10", "E13.11", "E11.00", "E11.01", "E13.00", "E13.01")
	replace acs = 1 if inlist(icdcode`j', "E10.65", "E10.69", "E11.65", "E11.69") 
	replace acs = 1 if inlist(icdcode`j', "E10.641, E11.641", "E106.610", "E106.618", "E10.620", "E10.621", "E10.622", "E10.628", "E10.630")
	replace acs = 1 if inlist(icdcode`j', "E10.638", "E10.641", "E10.649", "E11.649") 
	replace acs = 1 if inlist(icdcode`j', "E11.610", "E11.618", "E11.620", "E11.621", "E11.622", "E11.628", "E11.630", "E11.638", "E11.641")
	
	* Ear, nose and throat infections
	replace acs = 1 if inlist(icdcode`j', "H66.001", "H66.002", "H66.003", "H66.004", "H66.005", "H66.007", "H66.009", "H66.011", "H66.012")
	replace acs = 1 if inlist(icdcode`j', "H66.014", "H66.015", "H66.016", "H66.017", "H66.019", "H66.3X1", "H66.3X2", "H66.3X3", "H66.3X9")
	replace acs = 1 if inlist(icdcode`j', "H66.10", "H66.11", "H66.12", "H66.13", "H66.20", "H66.21", "H66.22", "H66.23", "H66.013") 
	replace acs = 1 if inlist(icdcode`j', "H66.40", "H66.41", "H66.42", "H66.43", "H66.90", "H66.91", "H66.92", "H66.93")
	replace acs = 1 if inlist(icdcode`j', "J03.00", "J03.01", "J03.80", "J03.81", "J03.90", "J03.91")

	replace acs = 1 if substr(icdcode`j',1,5) == "J02.0" | substr(icdcode`j',1,5) == "J02.8" | substr(icdcode`j',1,5) == "J02.9" | substr(icdcode`j',1,5) == "J04.0" | substr(icdcode`j',1,5) == "J06.0" | substr(icdcode`j',1,5) == "J06.9" | substr(icdcode`j',1,5) == "J31.2"

	* Hypertension
	replace acs = 1 if substr(icdcode`j',1,3) == "I10"
	replace acs = 1 if substr(icdcode`j',1,5) == "I11.9"
	
	* Hypoglycemia 
	replace acs = 1 if substr(icdcode`j',1,5) == "E16.2"
	
	* Influenza and pneumonia
	replace acs = 1 if substr(icdcode`j',1,3) == "A70" | substr(icdcode`j',1,3) == "J13" | substr(icdcode`j',1,3) == "J14" 
	replace acs = 1 if substr(icdcode`j',1,5) == "J16.0" | substr(icdcode`j',1,5) == "J16.8" | substr(icdcode`j',1,5) == "J18.1" | substr(icdcode`j',1,5) == "J18.2" | substr(icdcode`j',1,5) == "J18.8" | substr(icdcode`j',1,5) == "J18.9" | substr(icdcode`j',1,5) == "J10.1" | substr(icdcode`j',1,5) == "J10.2" | substr(icdcode`j',1,5) == "J11.1" | substr(icdcode`j',1,5) == "J11.2"
	replace acs = 1 if substr(icdcode`j',1,5) == "A48.1" | substr(icdcode`j',1,5) == "J15.3" | substr(icdcode`j',1,5) == "J15.4" | substr(icdcode`j',1,5) == "J15.7" | substr(icdcode`j',1,5) == "J15.9" | substr(icdcode`j',1,5) == "J12.0" | substr(icdcode`j',1,5) == "J12.1" | substr(icdcode`j',1,5) == "J12.2" | substr(icdcode`j',1,5) == "J12.3" | substr(icdcode`j',1,5) == "J12.81" | substr(icdcode`j',1,5) == "J12.89" | substr(icdcode`j',1,5) == "J12.9"

	replace acs = 1 if inlist(icdcode`j', "J10.00", "J10.01", "J10.08", "J10.81", "J10.82", "J10.83", "J10.89")
	replace acs = 1 if inlist(icdcode`j', "J11.00", "J11.08", "J11.81", "J11.82", "J11.83", "J11.89") 

	* Iron or other nutritional deficiency anaemia
	replace acs = 1 if substr(icdcode`j',1,5) == "D50.1" | substr(icdcode`j',1,5) == "D50.8" | substr(icdcode`j',1,5) == "D50.9" | substr(icdcode`j',1,5) == "D51.0" | substr(icdcode`j',1,5) == "D51.1" | substr(icdcode`j',1,5) == "D51.2" | substr(icdcode`j',1,5) == "D51.3" | substr(icdcode`j',1,5) == "D51.8" | substr(icdcode`j',1,5) == "D52.0" | substr(icdcode`j',1,5) == "D52.1" | substr(icdcode`j',1,5) == "D52.8" | substr(icdcode`j',1,5) == "D52.9" | substr(icdcode`j',1,5) == "D51.9"

	* Nutritional deficiency
	replace acs = 1 if substr(icdcode`j',1,3) == "E40" | substr(icdcode`j',1,3) == "E41" | substr(icdcode`j',1,3) == "E43"
	replace acs = 1 if substr(icdcode`j',1,5) == "E55.0" | substr(icdcode`j',1,5) == "E64.3"
	
	* Other vaccine preventable diseases	
	replace acs = 1 if substr(icdcode`j',1,3) == "A33" | substr(icdcode`j',1,3) == "A34" | substr(icdcode`j',1,3) == "A35"
	replace acs = 1 if substr(icdcode`j',1,5) == "A80.0" | substr(icdcode`j',1,5) == "A80.1" | substr(icdcode`j',1,5) == "A80.2" | substr(icdcode`j',1,5) == "A80.30" | substr(icdcode`j',1,5) == "A80.39" | substr(icdcode`j',1,5) == "A80.4" | substr(icdcode`j',1,5) == "A80.9" 
	replace acs = 1 if substr(icdcode`j',1,5) == "G00.0"
	replace acs = 1 if substr(icdcode`j',1,5) == "I01.0" | substr(icdcode`j',1,5) == "I01.1" | substr(icdcode`j',1,5) == "I01.2" | substr(icdcode`j',1,5) == "I01.8" | substr(icdcode`j',1,5) == "I01.9" 

	replace acs = 1 if inlist(icdcode`j', "A37.00", "A37.01", "A37.10", "A37.11", "A37.80", "A37.81", "A37.90", "A37.91")

	* Pelvic inflammatory disease
	replace acs = 1 if inlist(icdcode`j', "N70.01", "N70.02", "N70.03", "N70.11", "N70.12", "N70.13", "N70.91", "N70.92", "N70.93")
	replace acs = 1 if substr(icdcode`j',1,5) == "N73.0" | substr(icdcode`j',1,5) == "N73.1" | substr(icdcode`j',1,5) == "N73.2" | substr(icdcode`j',1,5) == "N73.3" | substr(icdcode`j',1,5) == "N73.4" | substr(icdcode`j',1,5) == "N73.5" | substr(icdcode`j',1,5) == "N73.6" | substr(icdcode`j',1,5) == "N73.8" | substr(icdcode`j',1,5) == "N73.9" 
	replace acs = 1 if substr(icdcode`j',1,3) == "N74"

	* Perforated/bleeding ulcer
	replace acs = 1 if substr(icdcode`j',1,5) == "K22.6" | substr(icdcode`j',1,5) == "K25.0" | substr(icdcode`j',1,5) == "K25.1" | substr(icdcode`j',1,5) == "K25.2" | substr(icdcode`j',1,5) == "K25.4" | substr(icdcode`j',1,5) == "K25.5" | substr(icdcode`j',1,5) == "K25.6" | substr(icdcode`j',1,5) == "K26.0" | substr(icdcode`j',1,5) == "K26.1" | substr(icdcode`j',1,5) == "K26.2" | substr(icdcode`j',1,5) == "K26.4" | substr(icdcode`j',1,5) == "K26.5"
	replace acs = 1 if substr(icdcode`j',1,5) == "K26.6" | substr(icdcode`j',1,5) == "K27.0" | substr(icdcode`j',1,5) == "K27.1" | substr(icdcode`j',1,5) == "K27.2" | substr(icdcode`j',1,5) == "K27.4" | substr(icdcode`j',1,5) == "K27.5" | substr(icdcode`j',1,5) == "K27.6" | substr(icdcode`j',1,5) == "K28.0" | substr(icdcode`j',1,5) == "K28.1" | substr(icdcode`j',1,5) == "K28.2" | substr(icdcode`j',1,5) == "K28.4" | substr(icdcode`j',1,5) == "K28.5"
	replace acs = 1 if substr(icdcode`j',1,5) == "K28.6" | substr(icdcode`j',1,5) == "K92.0" | substr(icdcode`j',1,5) == "K92.1" | substr(icdcode`j',1,5) == "K92.2"

	* Pyelonephritis
	replace acs = 1 if substr(icdcode`j',1,3) == "N10" | substr(icdcode`j',1,3) == "N12"
	replace acs = 1 if substr(icdcode`j',1,5) == "N11.0" | substr(icdcode`j',1,5) == "N11.1" | substr(icdcode`j',1,5) == "N11.8" | substr(icdcode`j',1,5) == "N11.9" | substr(icdcode`j',1,5) == "N13.6" | substr(icdcode`j',1,5) == "N15.9"

	* Appendicitis with rupture	
	replace acs = 1 if substr(icdcode`j',1,5) == "K35.2" | substr(icdcode`j',1,5) == "K35.3"
	replace acs = 1 if inlist(icdcode`j', "K35.80", "K35.89")
	replace acs = 1 if substr(icdcode`j',1,3) == "K36" | substr(icdcode`j',1,3) == "K37"
	
	di ""
	di ""
}	
tab acs, m

gen acs_diab = 0
forvalues j = 1/15 {
	* Diabetes complications
	replace acs_diab = 1 if substr(icdcode`j',1,5) == "E11.8" | substr(icdcode`j',1,5) == "E10.8" | substr(icdcode`j',1,5) == "E10.9" | substr(icdcode`j',1,5) == "E11.9" | substr(icdcode`j',1,5) == "E10.8" | substr(icdcode`j',1,5) == "E10.9"
	
	replace acs_diab = 1 if inlist(icdcode`j', "E10.10", "E10.11", "E13.10", "E13.11", "E11.00", "E11.01", "E13.00", "E13.01")
	replace acs_diab = 1 if inlist(icdcode`j', "E10.65", "E10.69", "E11.65", "E11.69") 
	replace acs_diab = 1 if inlist(icdcode`j', "E10.641, E11.641", "E106.610", "E106.618", "E10.620", "E10.621", "E10.622", "E10.628", "E10.630")
	replace acs_diab = 1 if inlist(icdcode`j', "E10.638", "E10.641", "E10.649", "E11.649") 
	replace acs_diab = 1 if inlist(icdcode`j', "E11.610", "E11.618", "E11.620", "E11.621", "E11.622", "E11.628", "E11.630", "E11.638", "E11.641") 	
}
tab acs_diab, m

/* billing Medical for HSF patient conditions *
gen can_bill_medical = 0
forvalues j = 1/15 {
	replace  if substr(icdcode`j',1,3) == ""
}	
tab can_bill_medical, m
*/

/* wellness visits */
* https://www.aafp.org/fpm/2014/0700/oa1.html
* https://www.icd10data.com/ICD10CM/Codes/Z00-Z99/Z00-Z13
gen wellness = 0
forvalues j = 1/15 {
	replace wellness = 1 if substr(icdcode`j',1,3) == "Z00" | substr(icdcode`j',1,3) == "Z01"  // child wellness and adult annual
		//  Encounter for general examination without complaint, suspected or reported diagnosis 
		//  Encounter for other examination without complaint, suspected or reported diagnosis 
	replace wellness = 1 if substr(icdcode`j',1,3) == "Z23"   // immunizations
}
tab wellness, m

label var pregnancy "pregnancy or delivery visit"
label var acs "Ambulatory-care sensitive condition"
label var acs_diab "Diabetes Ambulatory-care sensitive condition"
label var wellness "Child wellness, adult annual exam or immunization"
*label var can_bill_medical "diagnoses billed to Medical for HSF patients"

order icdcode*, last
desc
sum

isid ptid date
qui compress

save "../../Data/In/Vasco/PtDx_final.dta", replace


*******************************
***** 4. GENERATE GROUPS ******
*******************************
use "../../Data/In/Vasco/encFC_final.dta", clear

merge 1:1 ptid date using "../../Data/In/Vasco/PtDx_final.dta", gen(m1) keep(1 3)
drop m1

/* HSF always and HSF ever variables */
bysort ptid: egen hsf_always = mean(hsf)
replace hsf_always = hsf_always >= .98

bysort ptid: egen hsf_ever = mean(hsf)
replace hsf_ever = hsf_ever >= .02

/* Medical always and Medical ever variables */
/* first flag pregnancy and deliveries billed as medical to HSF ever patients as HSF claims */
replace medical = 0 if hsf_ever == 1 & medical == 1 & pregnancy == 1
*replace medical = 0 if hsf_ever == 1 & medical == 1 & can_bill_medical == 1

bysort ptid: egen medical_always = mean(medical)
replace medical_always = medical_always >= .98

bysort ptid: egen medical_ever = mean(medical)
replace medical_ever = medical_ever >= .02

bysort ptid: egen patient_pay_ever = mean(patient_pay)
replace patient_pay_ever = patient_pay_ever >= .02

/* HSF and Emergency Medicaid only */
gen not_hsf_only = 0
* make not_hsf_obly = 1 if not worker's comp, not patient pay, not HSF
replace not_hsf_only = 1 if inlist(fcode1, 5, 16, 19, 27) != 1 | inlist(fcode2, 5, 16, 19, 27) != 1     // patient pay, workers comp or HSF
* next, make not_hsf_only = 0 if medical & ER
replace not_hsf_only = 0 if (inlist(fcode1, 9, 10, 11, 20, 22) == 1 & emerg == 1) & inlist(fcode2, 5, 16, 19, 27) == 1
replace not_hsf_only = 0 if (inlist(fcode2, 9, 10, 11, 20, 22) == 1 & emerg == 1) & inlist(fcode1, 5, 16, 19, 27) == 1
* next, make not_hsf_only = 0 if medical & pregnancy
replace not_hsf_only = 0 if (inlist(fcode1, 9, 10, 11, 20, 22) == 1 & pregnancy == 1) & inlist(fcode2, 5, 16, 19, 27) == 1
replace not_hsf_only = 0 if (inlist(fcode2, 9, 10, 11, 20, 22) == 1 & pregnancy == 1) & inlist(fcode1, 5, 16, 19, 27) == 1

bysort ptid: egen hsf_only = total(not_hsf_only)
replace hsf_only = hsf_only == 0

/* Patient Appears in database before 2016 Presidential election */
bysort ptid: egen in_panel = min(date)
replace in_panel = in_panel < 20766

collapse (mean) medical_always hsf_always hsf_ever hsf_only medical_ever patient_pay_ever in_panel, by(ptid)

assert inlist(medical_always, 0, 1)
assert inlist(medical_ever, 0, 1)
assert inlist(hsf_always, 0, 1)
assert inlist(hsf_ever, 0, 1)
assert inlist(hsf_only, 0, 1)
assert inlist(patient_pay_ever, 0, 1)

tab medical_always, sort m
tab medical_ever, sort m
tab hsf_always, sort m
tab hsf_ever, sort m
tab hsf_only, sort m
tab patient_pay_ever, sort m

tab medical_always medical_ever
tab hsf_always hsf_ever
tab hsf_always hsf_only
tab hsf_ever hsf_only

merge 1:1 ptid using "../../Data/In/Vasco/PtDemo_final.dta" 
assert _merge ==3
drop _merge

qui compress
order in_panel patient* hsf* medical*, last

label var hsf_ever "Ever used HSF (in sample)"
label var hsf_always "Always using HSF (in sample)"
label var hsf_only "Only using HSF or Emergency Medical (in sample)"
label var medical_ever "Ever used Medical (in sample)"
label var medical_always "Always using Medical (in sample)"
label var in_panel "Patient appears before 2016 Presidential Election"
label var patient_pay_ever "Ever used Patient Pay (in sample)"

gen group = 0, after(ptid)
replace group = 1 if (hsf_always == 1)
replace group = 2 if (hsf_always == 0 & hsf_ever == 1 & hispan == 1)
replace group = 3 if (hsf_ever == 0 & medical_always == 1 & hispan == 1)
replace group = 4 if (hsf_ever == 0 & medical_always == 1 & hispan == 0)
replace group = 5 if group == 0
	
label define group_lbl ///
	1 "HSF Always" ///
	2 "HSF Ever, Hispanic" ///
	3 "HSF Never, Medical Always, Hispanic" ///
	4 "HSF Never, Medical Always, non-Hispanic" ///
	5 "Other", replace	
label values group group_lbl	

tab group, m 
tab group if in_panel == 1, m 
tab group if in_panel == 1 & age >= 18, m
 
save "../../Data/In/Vasco/PtDemo_final.dta", replace


******************************
******* MERGE DATASETS *******
******************************
use "../../Data/In/Vasco/PtDemo_final.dta", clear

merge 1:m ptid using "../../Data/In/Vasco/encFC_final.dta", gen(m1) keep(1 3)
assert m1 == 3
drop m1

merge 1:1 ptid date using "../../Data/In/Vasco/PtDx_final.dta", gen(m1) keep(1 3)
drop m1

keep if age >= 18
keep if in_panel == 1

order ptid date week group

/**** COLLAPSE TO WEEK LEVEL ****/

* CREATE VISIT TYPES
gen nvisits_tot = dental == 0 & psych == 0 & emerg == 0

rename psych nvisits_psych
rename emerg nvisits_emerg
rename urgentc nvisits_urgentc
rename primaryc nvisits_primaryc
rename lab nvisits_lab
rename dental nvisits_dental
rename acs nvisits_acs
rename acs_diab nvisits_acs_diab
rename wellness nvisits_wellness

gen nvisits_acs_emerg = nvisits_acs == 1 & nvisits_emerg == 1
gen nvisits_acs_diab_emerg = nvisits_acs_diab == 1 & nvisits_emerg == 1

replace nvisits_wellness = 0 if nvisits_primaryc == 0 & nvisits_wellness == 1

bysort ptid week: gen n = _n == 1    // =1 if a patient appears in a given week. to get number of patients per group-week

* AGGREGATE TO THE WEEK LEVEL
collapse (sum) nvisits* n, by(group week)

sort week group
order week group nvisits*

* CREATE LOGS
gen lnvisits_tot = log(nvisits_tot)
gen lnvisits_psych = log(nvisits_psych)
gen lnvisits_emerg = log(nvisits_emerg)
gen lnvisits_urgentc = log(nvisits_urgentc)
gen lnvisits_primaryc = log(nvisits_primaryc)
gen lnvisits_dental = log(nvisits_dental)
gen lnvisits_lab = log(nvisits_lab)
gen lnvisits_acs = log(nvisits_acs)
gen lnvisits_acs_diab = log(nvisits_acs_diab)
gen lnvisits_wellness = log(nvisits_wellness)
gen lnvisits_acs_emerg = log(nvisits_acs_emerg)
gen lnvisits_acs_diab_emerg = log(nvisits_acs_diab_emerg)

sum n*
sum ln*

label var nvisits_tot "# visits - total (non-dental, non-psych, non-emerg)"
label var nvisits_psych "# visits - psychiatry, mental health"
label var nvisits_emerg "# visits - emergency"
label var nvisits_urgentc "# visits - urgent care"
label var nvisits_lab "# visits - laboratory"
label var nvisits_dental "# visits - dental"
label var nvisits_primaryc "# visits - primary care/family clinic"
label var nvisits_acs "# visits - ambulatory-care sensitive (ACS)"
label var nvisits_acs_diab "# visits - ACS diabetes related"
label var nvisits_wellness "# visits - wellness"
label var nvisits_acs_emerg "# visits - ACS & emergency"
label var nvisits_acs_diab_emerg "# visits - ACS Diabetes & emergency"

label var lnvisits_tot "(log) # visits - total (non-dental, non-psych, non-emerg)"
label var lnvisits_psych "(log) # visits - psychiatry, mental health"
label var lnvisits_emerg "(log) # visits - emergency"
label var lnvisits_urgentc "(log) # visits - urgent care"
label var lnvisits_lab "(log) # visits - laboratory"
label var lnvisits_dental "(log) # visits - dental"
label var lnvisits_primaryc "(log) # visits - primary care/family clinic"
label var lnvisits_acs "(log) # visits - ambulatory-care sensitive (ACS)"
label var lnvisits_acs_diab "(log) # visits - ACS diabetes related"
label var lnvisits_wellness "(log) # visits - wellness"
label var lnvisits_acs_emerg "(log) # visits - ACS & emergency"
label var lnvisits_acs_diab_emerg "(log) # visits - ACS Diabetes & emergency"

tab group, m
capture drop _*

desc
sum
qui compress

drop if group == 5

save "../../Data/In/Vasco/final.dta", replace



*****************************
******* CHILDREN DATA *******
*****************************
clear
use "../../Data/In/Vasco/PtDemo_final.dta", clear

merge 1:m ptid using "../../Data/In/Vasco/encFC_final.dta", gen(m1) keep(1 3)
assert m1 == 3
drop m1

keep if age < 18
keep if in_panel == 1

unique ptid if hispan == 0
unique ptid if hispan == 1

rename hispan group

gen nvisits = 1
collapse (sum) nvisits, by(week group)

sum
gen lnvisits = log(nvisits)
sum

save "../../Data/In/Vasco/final_kids.dta", replace


*******************************
******* ADULT MALE DATA *******
*******************************
clear
use "../../Data/In/Vasco/PtDemo_final.dta", clear

merge 1:m ptid using "../../Data/In/Vasco/encFC_final.dta", gen(m1) keep(1 3)
assert m1 == 3
drop m1

keep if age >= 18 & age <= 64
keep if male == 1
keep if in_panel == 1

tab group, m
drop if group == 5

gen nvisits = 1
collapse (sum) nvisits, by(week group)

sum
gen lnvisits = log(nvisits)
sum

save "../../Data/In/Vasco/final_male.dta", replace


capture log close


** NOTE: FOR NOW NOT USING THE "ENCNUM" VARIABLE; MERGING BY PTID-DATE
** NOTE: FCs (MEDICAL, HSF) =1 if EITHER FC1 OR FC2 == MEDICAL, HSF (so a bit of double counting)
** NOTE: SAME FOR HOSPITAL SERVICE
** NOTE: NOT KEEPING HSF,CMAP,SSN *LATEST* and *CURRENT* VARIABLES
** NOTE: NOT KEEPING AGE AT ENCOUNTER
