*******************
**** LOAD DATA ****	
*******************
clear all
set more off
cd "/Users/yasenov/Desktop/replication"

use "data/final.dta"

****************
**** GRAPHS ****	
****************
global window = 4
global legend legend( ///
	label(1 "HSF Always") ///
	label(2 "HSF Ever, Hisp") ///
	label(3 "MediCal Always, Hisp") ///
	label(4 "MediCal Always, non-Hisp") ///
	pos(6) ring(1) rows(1))

global graph1 (line lnvisits_urgentc1 week, lpattern(solid)) ///
		(line lnvisits_urgentc2 week, lpattern(solid)) ///
		(line lnvisits_urgentc3 week, lpattern(dash)) ///
		(line lnvisits_urgentc4 week, lpattern(dash))

global graph2 (line lnvisits_primaryc1 week, lpattern(solid)) ///
		(line lnvisits_primaryc2 week, lpattern(solid)) ///
		(line lnvisits_primaryc3 week, lpattern(dash)) ///
		(line lnvisits_primaryc4 week, lpattern(dash))	
		
global graph3 (line lnvisits_emerg1 week, lpattern(solid)) ///
		(line lnvisits_emerg2 week, lpattern(solid)) ///
		(line lnvisits_emerg3 week, lpattern(dash)) ///
		(line lnvisits_emerg4 week, lpattern(dash))		
			
global graph4 (line lnvisits_wellness1 week, lpattern(solid)) ///
		(line lnvisits_wellness2 week, lpattern(solid)) ///
		(line lnvisits_wellness3 week, lpattern(dash)) ///
		(line lnvisits_wellness4 week, lpattern(dash))
		
/* reshape */	
local vars nvisits_emerg-lnvisits_wellness
keep `vars' week group
reshape wide `vars', i(week) j(group)

replace lnvisits_acs_diab_emerg1 = lnvisits_acs_diab_emerg1 + lnvisits_acs_diab_emerg2
replace lnvisits_acs_diab_emerg3 = lnvisits_acs_diab_emerg3 + lnvisits_acs_diab_emerg4
replace lnvisits_acs_emerg1 = lnvisits_acs_emerg1 + lnvisits_acs_emerg2
replace lnvisits_acs_emerg3 = lnvisits_acs_emerg3 + lnvisits_acs_emerg4

****************************************************************
/*	 EVENT #1: RUMORS, PANIC, PROTESTS, GOOGLE TRENDS SPIKE */
****************************************************************
* JAN 6, 2016
* DAYS: [20459]
* WEEKS: 2912
local IF if week >= 2912 - $window - 1 & week <= 2912 + $window

preserve
keep `IF'

twoway $graph1, ///
	xline(2911.5) ///
	$legend ///
	ylabel(1.5(1)4.5) ///
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #1: False ICE Raids in Oakland, Hayward", ring(0)) ///
	name(gr1_1, replace)

twoway $graph2, ///
	xline(2911.5) ///
	$legend ///
	ylabel(3.5(1)6.5) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #1: False ICE Raids in Oakland, Hayward", ring(0)) ///
	name(gr2_1, replace)

twoway $graph3, ///
	xline(2911.5) ///
	$legend ///
	ylabel(1(1)5) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #1: False ICE Raids in Oakland, Hayward", ring(0)) ///
	name(gr3_1, replace)

twoway $graph4, ///
	xline(2911.5) ///
	$legend ///
	ylabel(3(1)6) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #1: False ICE Raids in Oakland, Hayward", ring(0)) ///
	name(gr4_1, replace)

restore


*******************************************
/*	EVENT #2: 2016 PRESIDENTIAL ELECTION */
*******************************************
* NOV 08, 2016
* DAYS: 20766 
* WEEKS: 2956

local IF if week >= 2956 - $window - 1 & week <= 2956 + $window

preserve
keep `IF'

twoway $graph1, ///
	xline(2955.5) ///
	$legend ///
	ylabel(1.5(1)4.5) ///
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #2: Presidential Election", ring(0)) ///
	name(gr1_2, replace)

twoway $graph2, ///
	xline(2955.5) ///
	$legend ///
	ylabel(3.5(1)6.5) ///		
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #2: Presidential Election", ring(0)) ///
	name(gr2_2, replace)

twoway $graph3, ///
	xline(2955.5) ///
	$legend ///
	ylabel(1(1)5) ///		
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #2: Presidential Election", ring(0)) ///
	name(gr3_2, replace)

twoway $graph4, ///
	xline(2955.5) ///
	$legend ///
	ylabel(3(1)6) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #2: Presidential Election", ring(0)) ///
	name(gr4_2, replace)

restore

****************************************************************
/*	 EVENT #3.1: INNAGURATION, EXEC ORDER, ICE AT GOOD SAMARITAN */
****************************************************************/
* JAN 20, 25, 26, 2017
* DAYS: [20839 20844 20845]
* WEEKS: 2966

********************************************************************
/*	 EVENT #3.2: ICE raids rumor in Alameda and Contra Costa */
********************************************************************
* FEB 16, 2017
* DAYS: 20866
* WEEKS: 2970

local IF if week >= 2966 - $window - 1 & week <= 2966 + $window

preserve
keep `IF'

twoway $graph1, ///
	xline(2965.5) ///
	$legend ///
	ylabel(1.5(1)4.5) ///
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #3: Presidential Inaguration, Exec. Order, ICE Raid", ring(0)) ///
	name(gr1_3, replace)

twoway $graph2, ///
	xline(2965.5) ///
	$legend ///
	ylabel(3.5(1)6.5) ///		
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #3: Presidential Inaguration, Exec. Order, ICE Raid", ring(0)) ///
	name(gr2_3, replace)

twoway $graph3, ///
	xline(2965.5) ///
	$legend ///
	ylabel(1(1)5) ///		
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #3: Presidential Inaguration, Exec. Order, ICE Raid", ring(0)) ///
	name(gr3_3, replace)

twoway $graph4, ///
	xline(2965.5) ///
	$legend ///
	ylabel(3(1)6) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #3: Presidential Inaguration, Exec. Order, ICE Raid", ring(0)) ///
	name(gr4_3, replace)

restore	

********************************************
/*	 EVENT #4.1: ICE raid in Hayward */
********************************************
* JUL 27, 2017
* DAYS: 21027
* WEEKS: 2993

********************************************
/*	 EVENT #4.2: ICE raid in Oakland */
********************************************
* AUG 16, 2017
* DAYS: 21047
* WEEKS: 2996

local IF if week >= 2993 - $window - 1 & week <= 2993 + $window

preserve
keep `IF'

twoway $graph1, ///
	xline(2992.5) ///
	$legend ///
	ylabel(1.5(1)4.5) ///
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #4: ICE Raid in Hayward, Oakland", ring(0)) ///
	name(gr1_4, replace)

twoway $graph2, ///
	xline(2992.5) ///
	$legend ///
	ylabel(3.5(1)6.5) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #4: ICE Raid in Hayward, Oakland", ring(0)) ///
	name(gr2_4, replace)

twoway $graph3, ///
	xline(2992.5) ///
	$legend ///
	ylabel(1(1)5) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #4: ICE Raid in Hayward, Oakland", ring(0)) ///
	name(gr3_4, replace)

twoway $graph4, ///
	xline(2992.5) ///
	$legend ///
	xtitle("") ///
	ylabel(3(1)6) ///	
	ytitle("Log # of Visits") ///
	subtitle("Event #4: ICE Raid in Hayward, Oakland", ring(0)) ///
	name(gr4_4, replace)

restore

***************************************************
/*	 EVENT #5: ICE arrests in Santa Clara */
***************************************************
* SEP 29, 2017
* DAYS: 21091
* WEEKS: 3003
local IF if week >= 3002 - $window - 1 & week <= 3002 + $window

preserve
keep `IF'

twoway $graph1, ///
	xline(3001.5) ///
	$legend ///
	ylabel(1.5(1)4.5) ///
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #5: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr1_5, replace)

twoway $graph2, ///
	xline(3001.5) ///
	$legend ///
	ylabel(3.5(1)6.5) ///		
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #5: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr2_5, replace)

twoway $graph3, ///
	xline(3001.5) ///
	$legend ///
	ylabel(1(1)5) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #5: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr3_5, replace)

twoway $graph4, ///
	xline(3001.5) ///
	$legend ///
	ylabel(3(1)6) ///
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #5: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr4_5, replace)

restore

**********************************************************************
/*	 EVENT #6.1: ICE raids in Santa Clara, Santa Rosa Counties */
/*   EVENT #6.2: ICE raids rumors  */
**********************************************************************
* JAN 10, 17 2018
* DAYS: 21194, 21201
* WEEKS: 3017, 3018

**********************************************
/*	 EVENT #6.3: ICE raids */
**********************************************
* FEB 01, 2018
* DAYS: 21216 
* WEEKS: 3020

local IF if week >= 3017 - $window - 1 & week <= 3017 + $window

preserve
keep `IF'

twoway $graph1, ///
	xline(3016.5) ///
	$legend ///
	ylabel(1.5(1)4.5) ///
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #6: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr1_6, replace)

twoway $graph2, ///
	xline(3016.5) ///
	$legend ///
	ylabel(3.5(1)6.5) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #6: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr2_6, replace)

twoway $graph3, ///
	xline(3016.5) ///
	$legend ///
	ylabel(1(1)5) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #6: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr3_6, replace)

twoway $graph4, ///
	xline(3016.5) ///
	$legend ///
	ylabel(3(1)6) ///	
	xtitle("") ///
	ytitle("Log # of Visits") ///
	subtitle("Event #6: Widespread ICE Raids in the Bay Area", ring(0)) ///
	name(gr4_6, replace)

restore



***************
***************
***************

* FAMILY CLINIC VISITS 
grc1leg gr2_1 gr2_2 gr2_3 gr2_4 gr2_5 gr2_6, r(3) imargin(vsmall) legendfrom(gr2_1) subtitle("Family Clinic Visits")
graph export "../results/fig_trends_pc.png", replace		
graph export "../results/fig_trends_pc.pdf", replace

* ANNUAL CHECKUP VISITS
grc1leg gr4_1 gr4_2 gr4_3 gr4_4 gr4_5 gr4_6, r(3) imargin(vsmall) legendfrom(gr4_1) subtitle("Annual Check-up Visits")
graph export "../results/fig_trends_wl.png", replace		
graph export "../results/fig_trends_wl.pdf", replace		

* URGENT CARE VISITS 
grc1leg gr1_1 gr1_2 gr1_3 gr1_4 gr1_5 gr1_6, r(3) imargin(vsmall) legendfrom(gr1_1) subtitle("Urgent Care Visits")
graph export "../results/fig_trends_uc.png", replace		
graph export "../results/fig_trends_uc.pdf", replace

* EMERGENCY DEPARTMENT VISITS
grc1leg gr3_1 gr3_2 gr3_3 gr3_4 gr3_5 gr3_6, r(3) imargin(vsmall) legendfrom(gr3_1) subtitle("Emergency Department Visits")
graph export "../results/fig_trends_ed.png", replace		
graph export "../results/fig_trends_ed.pdf", replace
