*******************
**** LOAD DATA ****	
*******************
clear all
set more off
cd "/Users/yasenov/Desktop/replication"

capture log close
log using "logs/regressions", replace

use "data/final.dta"
merge m:1 week using "data/events.dta"

*********************
**** REGRESSIONS ****	
*********************
global window 4

gen interaction1 = (group <= 2) * (week >= 2912)
gen interaction2 = (group <= 2) * (week >= 2956)
gen interaction3 = (group <= 2) * (week >= 2966)
gen interaction4 = (group <= 2) * (week >= 2993)
gen interaction5 = (group <= 2) * (week >= 3002)
gen interaction6 = (group <= 2) * (week >= 3017)

gen interaction_pooled = (group <= 2) * (event1 == 1) + (group <= 2) * (event2 == 1) + (group <= 2) * (event3 == 1) + (group <= 2) * (event4 == 1)  + (group <= 2) * (event5 == 1)  + (group <= 2) * (event6 == 1)
gen interaction_major = (group <= 2) * (event5 == 1)  + (group <= 2) * (event6 == 1)

****************
**** LABELS ****	
****************
label var interaction1 "Diff-in-Diff"
label var interaction2 "Diff-in-Diff"
label var interaction3 "Diff-in-Diff"
label var interaction4 "Diff-in-Diff"
label var interaction5 "Diff-in-Diff"
label var interaction6 "Diff-in-Diff"
label var interaction_pooled "Diff-in-Diff"

*********************
** FAMILY CLINICS ***
*********************
eststo clear
eststo: qui reg lnvisits_primaryc i.group interaction_pooled i.week if event1 != . | event2 != . | event3 != . | event4 != . | event5 != . | event6 != .
qui estadd ysumm
eststo: qui reg lnvisits_primaryc i.group interaction1 i.week if week >= 2912 - $window - 1 & week <= 2912 + $window
qui estadd ysumm
eststo: qui reg lnvisits_primaryc i.group interaction2 i.week if week >= 2956 - $window - 1 & week <= 2956 + $window
qui estadd ysumm
eststo: qui reg lnvisits_primaryc i.group interaction3 i.week if week >= 2966 - $window - 1 & week <= 2966 + $window
qui estadd ysumm
eststo: qui reg lnvisits_primaryc i.group interaction4 i.week if week >= 2993 - $window - 1 & week <= 2993 + $window
qui estadd ysumm
eststo: qui reg lnvisits_primaryc i.group interaction5 i.week if week >= 3002 - $window - 1 & week <= 3002 + $window
qui estadd ysumm
eststo: qui reg lnvisits_primaryc i.group interaction6 i.week if week >= 3017 - $window - 1 & week <= 3017 + $window
qui estadd ysumm


esttab, keep(interaction*) b(%4.3f) se(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label
esttab, keep(interaction*) b(%4.3f) ci(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label
	

*********************
** WELLNESS VISIT ***
*********************
eststo clear
eststo: qui reg lnvisits_wellness i.group interaction_pooled i.week if event1 != . | event2 != . | event3 != . | event5 != . | event6 != . | event6 != .
qui estadd ysumm
eststo: qui reg lnvisits_wellness i.group interaction1 i.week if week >= 2912 - $window - 1 & week <= 2912 + $window
qui estadd ysumm
eststo: qui reg lnvisits_wellness i.group interaction2 i.week if week >= 2956 - $window - 1 & week <= 2956 + $window
qui estadd ysumm
eststo: qui reg lnvisits_wellness i.group interaction3 i.week if week >= 2966 - $window - 1 & week <= 2966 + $window
qui estadd ysumm
eststo: qui reg lnvisits_wellness i.group interaction4 i.week if week >= 2993 - $window - 1 & week <= 2993 + $window
qui estadd ysumm
eststo: qui reg lnvisits_wellness i.group interaction5 i.week if week >= 3002 - $window - 1 & week <= 3002 + $window
qui estadd ysumm
eststo: qui reg lnvisits_wellness i.group interaction6 i.week if week >= 3017 - $window - 1 & week <= 3017 + $window
qui estadd ysumm

esttab, keep(interaction*) b(%4.3f) se(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label
esttab, keep(interaction*) b(%4.3f) ci(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label
	
	
******************
** URGENT CARE ***
******************
eststo clear
eststo: qui reg lnvisits_urgentc i.group interaction_pooled i.week if event1 != . | event2 != . | event3 != . | event5 != . | event6 != . | event6 != .
qui estadd ysumm
eststo: qui reg lnvisits_urgentc i.group interaction1 i.week if week >= 2912 - $window - 1 & week <= 2912 + $window
qui estadd ysumm
eststo: qui reg lnvisits_urgentc i.group interaction2 i.week if week >= 2956 - $window - 1 & week <= 2956 + $window
qui estadd ysumm
eststo: qui reg lnvisits_urgentc i.group interaction3 i.week if week >= 2966 - $window - 1 & week <= 2966 + $window
qui estadd ysumm
eststo: qui reg lnvisits_urgentc i.group interaction4 i.week if week >= 2993 - $window - 1 & week <= 2993 + $window
qui estadd ysumm
eststo: qui reg lnvisits_urgentc i.group interaction5 i.week if week >= 3002 - $window - 1 & week <= 3002 + $window
qui estadd ysumm
eststo: qui reg lnvisits_urgentc i.group interaction6 i.week if week >= 3017 - $window - 1 & week <= 3017 + $window
qui estadd ysumm


esttab, keep(interaction*) b(%4.3f) se(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label
esttab, keep(interaction*) b(%4.3f) ci(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label


*********************
** EMERGENCY ROOM ***
*********************
eststo clear
eststo: qui reg lnvisits_emerg i.group interaction_pooled i.week if event1 != . | event2 != . | event3 != . | event5 != . | event6 != . | event6 != .
qui estadd ysumm
eststo: qui reg lnvisits_emerg i.group interaction1 i.week if week >= 2912 - $window - 1 & week <= 2912 + $window
qui estadd ysumm
eststo: qui reg lnvisits_emerg i.group interaction2 i.week if week >= 2956 - $window - 1 & week <= 2956 + $window
qui estadd ysumm
eststo: qui reg lnvisits_emerg i.group interaction3 i.week if week >= 2966 - $window - 1 & week <= 2966 + $window
qui estadd ysumm
eststo: qui reg lnvisits_emerg i.group interaction4 i.week if week >= 2993 - $window - 1 & week <= 2993 + $window
qui estadd ysumm
eststo: qui reg lnvisits_emerg i.group interaction5 i.week if week >= 3002 - $window - 1 & week <= 3002 + $window
qui estadd ysumm
eststo: qui reg lnvisits_emerg i.group interaction6 i.week if week >= 3017 - $window - 1 & week <= 3017 + $window
qui estadd ysumm


esttab, keep(interaction*) b(%4.3f) se(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label
esttab, keep(interaction*) b(%4.3f) ci(%4.3f) stats(N r2 ymean, fmt(%2.0f %3.2f %3.2f) nostar labels("Observations" "R$^2$" "$\bar{Y}$")) label
		


capture log close

