clear all
set more off
cd "N:\UCSF ARS\RITM0160535\2018 1216"

capture log close
log using "../../Data/In/Vasco/sum_stats", replace

**********
********** PATIENT LEVEL VARIABLES
**********
use "../../Data/In/Vasco/PtDemo_final.dta"

keep if age >= 18
keep if in_panel == 1
drop if group == 5

sum
tab group

********
********

label var white "White"
label var white_non_hisp "White, non-Hispanic"
label var asian "Asian"
label var black "Black"
label var hispan "Hispanic"
label var age "Age"
label var male "Male"
label var english "English Language"
label var spanish "Spanish Language"

global vars male age white* hispan asian black english spanish // canton
sum $vars

eststo clear
eststo: qui estpost sum $vars 
bysort group: eststo: qui estpost sum $vars

esttab,	///
	label ///
	cells("mean(fmt(2))" "sd(par fmt(2))") ///
	nonumber nonotes ///
	mtitles("\shortstack{Full \\ Sample}" "\shortstack{ \\ HSF Always}" "\shortstack{HSF Ever \\ Hispanic}" "\shortstack{MediCal Always \\ Hispanic}" "\shortstack{MediCal Always \\ non-Hispanic}") ///
	mgroups("" "Treatment" "Control", pattern(1 1 0 1 0))

esttab using "../../Data/In/Vasco/sumstats.tex",	///
	label replace ///
	cells("mean(fmt(2))" "sd(par fmt(2))") ///
	nonumber nonotes ///
	mtitles("Full Sample" "HSF Always" "HSF Ever, Hisp." "MediCal Always, Hisp." "MediCal Always, non-Hisp.") ///
	mgroups("" "Treatment" "Control", pattern(1 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})span erepeat(\cmidrule(lr){@span})) ///
	prehead("{\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}\begin{tabular}{l*{5}{c}}\hline\hline \\ & \multicolumn{5}{c}{\textbf{Panel A: Patient-Level Variables}} \\\cmidrule(lr){2-6} %") ///
	postfoot("")

**********
********** ENCOUNTER LEVEL VARIABLES
**********

clear
use "../../Data/In/Vasco/PtDx_final.dta"
	
merge m:1 ptid using  "../../Data/In/Vasco/PtDemo_final.dta", gen(m1) keep(1 3)	
merge 1:1 ptid date using  "../../Data/In/Vasco/encFC_final.dta", gen(m2) keep(1 3)
assert m1 == 3
drop m1 m2

keep if age >= 18
keep if in_panel == 1
drop if group == 5

tab group, m

********
********

label var emerg "ED visit"
label var urgentc "Urgent Care Visit"
label var primaryc "Family Clinic Visit"

label var hsf "HSF Claim"
label var medical "Medical Claim"

global vars emerg urgentc primaryc hsf medical
sum $vars

eststo clear
eststo: qui estpost sum $vars 
bysort group: eststo: qui estpost sum $vars

esttab,	///
	label ///
	cells("mean(fmt(2))" "sd(par fmt(2))") ///
	nonumber nonotes ///
	mtitles("Full Sample" "HSF Always" "HSF Ever, Hisp." "Medical Always, Hisp." "Medical Always, non-Hisp.") ///
	mgroups("" "Treatment" "Control", pattern(1 1 0 1 0))

esttab using "../../Data/In/Vasco/sumstats.tex",	///
	label append ///
	cells("mean(fmt(2))" "sd(par fmt(2))") ///
	nonumber nonotes ///
	mtitles("\shortstack{Full \\ Sample}" "\shortstack{ \\ HSF Always}" "\shortstack{HSF Ever \\ Hispanic}" "\shortstack{Medical Always \\ Hispanic}" "\shortstack{Medical Always \\ non-Hispanic}") ///
	mgroups("" "Treatment" "Control", pattern(1 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(})span erepeat(\cmidrule(lr){@span})) ///
	prehead("\\ & \multicolumn{5}{c}{\textbf{Panel B: Visit-Level Variables}} \\\cmidrule(lr){2-6} %")

log close
